Index: /issm/trunk-jpl/externalpackages/gmt/configs/6.5/cmake/ConfigUserAdvancedTemplate.cmake.patch
===================================================================
--- /issm/trunk-jpl/externalpackages/gmt/configs/6.5/cmake/ConfigUserAdvancedTemplate.cmake.patch	(revision 28178)
+++ /issm/trunk-jpl/externalpackages/gmt/configs/6.5/cmake/ConfigUserAdvancedTemplate.cmake.patch	(revision 28178)
@@ -0,0 +1,115 @@
+--- ./src/cmake/ConfigUserAdvancedTemplate.cmake	2024-01-07 01:32:40
++++ ./ConfigUserAdvancedTemplate.cmake	2024-03-23 11:15:43
+@@ -1,5 +1,5 @@
+ #
+-# Copyright (c) 1991-2024 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
++# Copyright (c) 1991-2022 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ # See LICENSE.TXT file for copying and redistribution conditions.
+ #
+ # This program is free software; you can redistribute it and/or modify it
+@@ -46,12 +46,12 @@
+ #set (GMT_INSTALL_TRADITIONAL_FOLDERNAMES OFF)
+ 
+ # Make executables relocatable on supported platforms (relative RPATH) [FALSE]:
+-#set (GMT_INSTALL_RELOCATABLE TRUE)
++set (GMT_INSTALL_RELOCATABLE TRUE)
+ 
+ # Exclude optional GEOS, PCRE, PCRE2, FFTW3, LAPACK, BLAS, ZLIB dependencies even if you have them installed [FALSE]
+ #set (GMT_EXCLUDE_GEOS TRUE)
+-#set (GMT_EXCLUDE_PCRE TRUE)
+-#set (GMT_EXCLUDE_PCRE2 TRUE)
++set (GMT_EXCLUDE_PCRE TRUE)
++set (GMT_EXCLUDE_PCRE2 TRUE)
+ #set (GMT_EXCLUDE_FFTW3 TRUE)
+ #set (GMT_EXCLUDE_LAPACK TRUE)
+ #set (GMT_EXCLUDE_BLAS TRUE)
+@@ -100,11 +100,11 @@
+ 
+ # Set location of NetCDF (can be root directory, path to header file or path
+ # to nc-config) [auto]:
+-#set (NETCDF_ROOT "netcdf_install_prefix")
++set (NETCDF_ROOT "$ENV{NETCDF_ROOT}")
+ 
+ # Set location of GDAL (can be root directory, path to header file or path to
+ # gdal-config) [auto]:
+-#set (GDAL_ROOT "gdal_install_prefix")
++set (GDAL_ROOT "$ENV{GDAL_ROOT}")
+ 
+ # Set location of GEOS (can be root directory, path to header file or path to
+ # geos-config) [auto]:
+@@ -122,14 +122,14 @@
+ #set (FFTW3_ROOT "fftw_install_prefix")
+ 
+ # Set location of ZLIB (can be root directory or path to header file) [auto]:
+-#set (ZLIB_ROOT "zlib_install_prefix")
++set (ZLIB_ROOT "$ENV{ZLIB_ROOT}")
+ 
+ # Set location of CURL (can be root directory or path to header file) [auto]:
+-#set (CURL_ROOT "curl_install_prefix")
++set (CURL_ROOT "$ENV{CURL_ROOT}")
+ 
+ # Set location of GLIB component gthread [auto].  This is an optional (and
+-# experimental) option which you need to enable or disable:
+-set (GMT_USE_THREADS TRUE)
++# experimental) option which you need to enable:
++#set (GMT_USE_THREADS TRUE)
+ # If pkg-config is not installed (e.g. on Windows) you need to specify these:
+ #set (GLIB_INCLUDE_DIR c:/path/to/glib-dev/include/glib-2.0)
+ #set (GLIB_LIBRARIES c:/path/to/glib-dev/lib/glib-2.0.lib)
+@@ -148,7 +148,7 @@
+ #set (LICENSE_RESTRICTED GPL)
+ 
+ # Allow building of OpenMP if compiler supports it
+-set (GMT_ENABLE_OPENMP TRUE)
++#set (GMT_ENABLE_OPENMP TRUE)
+ 
+ # Configure default units (possible values are SI and US) [SI]:
+ #set (UNITS "US")
+@@ -163,7 +163,7 @@
+ #set (CMAKE_POSITION_INDEPENDENT_CODE TRUE)
+ 
+ # Build GMT shared lib with supplemental modules [TRUE]:
+-#set (BUILD_SUPPLEMENTS FALSE)
++set (BUILD_SUPPLEMENTS FALSE)
+ 
+ # Build/Install GMT Developer include files [TRUE]:
+ # This installs the extra include files and configured files needed by 3rd-party
+@@ -204,8 +204,9 @@
+ #set (DO_SUPPLEMENT_TESTS ON)
+ 
+ # Uncomment the following line if you need to run the full tests suite using
+-# the gmtserver "static" distribution instead of the default server.
+-# set (GMT_DATA_SERVER "static")
++# the gmtserver "test" distribution instead of the default server.
++# You may wish to rename existing cache and server dirs so you can restore afterwards
++# set (GMT_DATA_SERVER "test")
+ 
+ # List extra sub-dirs of 'src' with a CMakeLists.txt to build custom modules
+ # that link against the full gmt libs. (For building codes that only need the GMT API,
+@@ -218,8 +219,8 @@
+ #set (GMT_RELEASE_PREFIX "release-src-prefix")
+ 
+ # If set to false, image conversion from PS images to PNG and PDF does
+-# not depend on the gmt binary target. It assumes that you already have the
+-# gmt executable in your PATH [TRUE].
++# not depend on the gmt binary target. Note: "make gmt" is then required
++# before docs_depends [TRUE].
+ #set (GMT_DOCS_DEPEND_ON_GMT FALSE)
+ 
+ #
+@@ -236,14 +237,9 @@
+ #	add_definitions(-DDEBUG_MODERN)			# To set PPID == 0 during Xcode test
+ #	message("Add Xcode definition for GMT")
+ #endif()
+-
+-# Uncomment if you want to temporarily replace Miller projection with the "Christmas" projection.
+-# add_definitions(-DCHRISTMAS)
+-# Then, rebuild GMT and try the script share/tools/christmas-cube.sh
+-
+ # Uncomment these two statements if you are a developer debugging GMT:
+ #add_definitions(-DDEBUG)
+-#add_definitions(-DMEMDEBUG) # Turn on memory tracking; see gmt_memory .c on MEMDEBUG for information
++#add_definitions(-DMEMDEBUG) # Turn on memory tracking see gmt_support.c for extra info
+ #add_definitions(-DUSE_COMMON_LONG_OPTIONS) 	# Turn on testing of upcoming long-option syntax for common GMT options
+ #add_definitions(-DUSE_MODULE_LONG_OPTIONS) 	# Turn on testing of upcoming long-option syntax for module options
+ #add_definitions(-DEXPORT_GMTLIB)				# Turn on to access normally un-exported or static gmtlib functions from external tools
Index: /issm/trunk-jpl/externalpackages/gmt/configs/6.5/cmake/modules/ConfigCMake.cmake.patch
===================================================================
--- /issm/trunk-jpl/externalpackages/gmt/configs/6.5/cmake/modules/ConfigCMake.cmake.patch	(revision 28178)
+++ /issm/trunk-jpl/externalpackages/gmt/configs/6.5/cmake/modules/ConfigCMake.cmake.patch	(revision 28178)
@@ -0,0 +1,11 @@
+--- ./src/cmake/modules/ConfigCMake.cmake	2024-01-07 01:32:40
++++ ./ConfigCMake.cmake	2024-03-23 11:21:06
+@@ -195,7 +195,7 @@
+ 			# CMP0042: CMake 3.0: MACOSX_RPATH is enabled by default
+ 			set (CMAKE_MACOSX_RPATH ON)
+ 			set (CMAKE_INSTALL_NAME_DIR @rpath)
+-			set (CMAKE_INSTALL_RPATH "@rpath;@executable_path/${_rpath}")
++			set (CMAKE_INSTALL_RPATH "@rpath;@executable_path/${_rpath};${LIBGFORTRAN_ROOT}")
+ 		else (APPLE)
+ 			# relative RPATH on Linux, Solaris, etc.
+ 			set (CMAKE_INSTALL_RPATH "\$ORIGIN/${_rpath}")
Index: /issm/trunk-jpl/externalpackages/gmt/configs/6.5/static/cmake/ConfigUserAdvancedTemplate.cmake.patch
===================================================================
--- /issm/trunk-jpl/externalpackages/gmt/configs/6.5/static/cmake/ConfigUserAdvancedTemplate.cmake.patch	(revision 28178)
+++ /issm/trunk-jpl/externalpackages/gmt/configs/6.5/static/cmake/ConfigUserAdvancedTemplate.cmake.patch	(revision 28178)
@@ -0,0 +1,63 @@
+--- ./src/cmake/ConfigUserAdvancedTemplate.cmake	2024-01-07 01:32:40
++++ ./ConfigUserAdvancedTemplate.cmake	2024-03-23 11:00:04
+@@ -46,12 +46,12 @@
+ #set (GMT_INSTALL_TRADITIONAL_FOLDERNAMES OFF)
+ 
+ # Make executables relocatable on supported platforms (relative RPATH) [FALSE]:
+-#set (GMT_INSTALL_RELOCATABLE TRUE)
++set (GMT_INSTALL_RELOCATABLE TRUE)
+ 
+ # Exclude optional GEOS, PCRE, PCRE2, FFTW3, LAPACK, BLAS, ZLIB dependencies even if you have them installed [FALSE]
+ #set (GMT_EXCLUDE_GEOS TRUE)
+-#set (GMT_EXCLUDE_PCRE TRUE)
+-#set (GMT_EXCLUDE_PCRE2 TRUE)
++set (GMT_EXCLUDE_PCRE TRUE)
++set (GMT_EXCLUDE_PCRE2 TRUE)
+ #set (GMT_EXCLUDE_FFTW3 TRUE)
+ #set (GMT_EXCLUDE_LAPACK TRUE)
+ #set (GMT_EXCLUDE_BLAS TRUE)
+@@ -100,11 +100,11 @@
+ 
+ # Set location of NetCDF (can be root directory, path to header file or path
+ # to nc-config) [auto]:
+-#set (NETCDF_ROOT "netcdf_install_prefix")
++set (NETCDF_ROOT "$ENV{NETCDF_ROOT}")
+ 
+ # Set location of GDAL (can be root directory, path to header file or path to
+ # gdal-config) [auto]:
+-#set (GDAL_ROOT "gdal_install_prefix")
++set (GDAL_ROOT "$ENV{GDAL_ROOT}")
+ 
+ # Set location of GEOS (can be root directory, path to header file or path to
+ # geos-config) [auto]:
+@@ -122,10 +122,10 @@
+ #set (FFTW3_ROOT "fftw_install_prefix")
+ 
+ # Set location of ZLIB (can be root directory or path to header file) [auto]:
+-#set (ZLIB_ROOT "zlib_install_prefix")
++set (ZLIB_ROOT "$ENV{ZLIB_ROOT}")
+ 
+ # Set location of CURL (can be root directory or path to header file) [auto]:
+-#set (CURL_ROOT "curl_install_prefix")
++set (CURL_ROOT "$ENV{CURL_ROOT}")
+ 
+ # Set location of GLIB component gthread [auto].  This is an optional (and
+ # experimental) option which you need to enable or disable:
+@@ -163,7 +163,7 @@
+ #set (CMAKE_POSITION_INDEPENDENT_CODE TRUE)
+ 
+ # Build GMT shared lib with supplemental modules [TRUE]:
+-#set (BUILD_SUPPLEMENTS FALSE)
++set (BUILD_SUPPLEMENTS FALSE)
+ 
+ # Build/Install GMT Developer include files [TRUE]:
+ # This installs the extra include files and configured files needed by 3rd-party
+@@ -281,7 +281,7 @@
+ #set (CMAKE_INSTALL_SYSTEM_RUNTIME_LIBS c:/Windows/System32/msvcr100.dll)
+ 
+ # If your NetCDF library is static (not recommended, applies to Windows only)
+-#set (NETCDF_STATIC TRUE)
++set (NETCDF_STATIC TRUE)
+ 
+ # If want to rename the DLLs to something else than the default (e.g. to
+ # append the bitness - Windows only)
Index: /issm/trunk-jpl/externalpackages/gmt/install-6-mac-static.sh
===================================================================
--- /issm/trunk-jpl/externalpackages/gmt/install-6-mac-static.sh	(revision 28177)
+++ /issm/trunk-jpl/externalpackages/gmt/install-6-mac-static.sh	(revision 28178)
@@ -2,4 +2,13 @@
 set -eu
 
+# NOTE: After GMT version 6.0.0, we must build a shared copy of libgmt for our 
+# distributables as GMT moved from individual executables to a single 
+# executable with modules. For example,
+#
+#	gmtselect -> gmt select
+#
+# These modules are not compiled into the static version of libgmt (and likely) 
+# never will be.
+#
 
 ## Constants
@@ -51,5 +60,5 @@
 
 # Patch source
-patch ./src/cmake/ConfigUser.cmake < ./configs/${VER%.*}/static/mac/cmake/ConfigUserAdvancedTemplate.cmake.patch
+patch ./src/cmake/ConfigUser.cmake < ./configs/${VER%.*}/static/cmake/ConfigUserAdvancedTemplate.cmake.patch
 patch ./src/cmake/modules/FindGDAL.cmake < ./configs/${VER%.*}/static/cmake/modules/FindGDAL.cmake.patch
 patch ./src/cmake/modules/FindGSHHG.cmake < ./configs/${VER%.*}/static/cmake/modules/FindGSHHG.cmake.patch
Index: /issm/trunk-jpl/externalpackages/petsc/install-3.20-linux-static.sh
===================================================================
--- /issm/trunk-jpl/externalpackages/petsc/install-3.20-linux-static.sh	(revision 28178)
+++ /issm/trunk-jpl/externalpackages/petsc/install-3.20-linux-static.sh	(revision 28178)
@@ -0,0 +1,57 @@
+#!/bin/bash
+set -eu
+
+
+## Constants
+#
+VER="3.20.5"
+
+PETSC_DIR="${ISSM_DIR}/externalpackages/petsc/src" # DO NOT CHANGE THIS
+PREFIX="${ISSM_DIR}/externalpackages/petsc/install" # Set to location where external package should be installed
+
+# Download source
+$ISSM_DIR/scripts/DownloadExternalPackage.sh "https://issm.ess.uci.edu/files/externalpackages/petsc-lite-${VER}.tar.gz" "petsc-${VER}.tar.gz"
+
+# Unpack source
+tar -zxvf petsc-${VER}.tar.gz
+
+# Cleanup
+rm -rf ${PREFIX} ${PETSC_DIR}
+mkdir -p ${PETSC_DIR}
+
+# Move source to $PETSC_DIR
+mv petsc-${VER}/* ${PETSC_DIR}
+rm -rf petsc-${VER}
+
+# Configure
+#
+# NOTE:
+# - Cannot use --with-fpic option when compiling static libs,
+#
+#		Cannot determine compiler PIC flags if shared libraries is turned off
+#		Either run using --with-shared-libraries or --with-pic=0 and supply the
+#		compiler PIC flag via CFLAGS, CXXXFLAGS, and FCFLAGS
+#
+cd ${PETSC_DIR}
+./configure \
+	--prefix="${PREFIX}" \
+	--PETSC_DIR="${PETSC_DIR}" \
+	--with-shared-libraries=0 \
+	--CFLAGS="-fPIC" \
+	--CXXFLAGS="-fPIC" \
+	--FFLAGS="-fPIC" \
+	--with-debugging=0 \
+	--with-valgrind=0 \
+	--with-x=0 \
+	--with-ssl=0 \
+	--download-fblaslapack=1 \
+	--download-mpich=1 \
+	--download-metis=1 \
+	--download-parmetis=1 \
+	--download-scalapack=1 \
+	--download-mumps=1 \
+	--download-zlib=1
+
+# Compile and install
+make
+make install
Index: /issm/trunk-jpl/externalpackages/petsc/install-3.20-linux.sh
===================================================================
--- /issm/trunk-jpl/externalpackages/petsc/install-3.20-linux.sh	(revision 28178)
+++ /issm/trunk-jpl/externalpackages/petsc/install-3.20-linux.sh	(revision 28178)
@@ -0,0 +1,45 @@
+#!/bin/bash
+set -eu
+
+## Constants
+#
+VER="3.20.5"
+
+PETSC_DIR="${ISSM_DIR}/externalpackages/petsc/src" # DO NOT CHANGE THIS
+PREFIX="${ISSM_DIR}/externalpackages/petsc/install" # Set to location where external package should be installed
+
+# Download source
+$ISSM_DIR/scripts/DownloadExternalPackage.sh "https://issm.ess.uci.edu/files/externalpackages/petsc-lite-${VER}.tar.gz" "petsc-${VER}.tar.gz"
+
+# Unpack source
+tar -zxvf petsc-${VER}.tar.gz
+
+# Cleanup
+rm -rf ${PREFIX} ${PETSC_DIR}
+mkdir -p ${PETSC_DIR}
+
+# Move source to $PETSC_DIR
+mv petsc-${VER}/* ${PETSC_DIR}
+rm -rf petsc-${VER}
+
+# Configure
+cd ${PETSC_DIR}
+./configure \
+	--prefix="${PREFIX}" \
+	--PETSC_DIR="${PETSC_DIR}" \
+	--with-debugging=0 \
+	--with-valgrind=0 \
+	--with-x=0 \
+	--with-ssl=0 \
+	--with-pic=1 \
+	--download-fblaslapack=1 \
+	--download-mpich=1 \
+	--download-metis=1 \
+	--download-parmetis=1 \
+	--download-scalapack=1 \
+	--download-mumps=1 \
+	--download-zlib=1
+
+# Compile and install
+make
+make install
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-adolc-ampioff
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-adolc-ampioff	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-adolc-ampioff	(revision 28178)
@@ -44,5 +44,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	gsl			install.sh
 	triangle	install-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-adolc-ampion
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-adolc-ampion	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-adolc-ampion	(revision 28178)
@@ -44,5 +44,5 @@
 	autotools		install-linux.sh
 	cmake			install.sh
-	petsc			install-3.17-linux.sh
+	petsc			install-3.20-linux.sh
 	gsl				install.sh
 	triangle		install-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-basic
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-basic	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-basic	(revision 28178)
@@ -33,5 +33,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	triangle	install-linux.sh
 	m1qn3		install-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-binaries-matlab
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-binaries-matlab	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-binaries-matlab	(revision 28178)
@@ -45,5 +45,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux-static.sh
+	petsc		install-3.20-linux-static.sh
 	gsl			install-static.sh
 	boost		install-1.7-linux-static.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-binaries-python-3
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-binaries-python-3	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-binaries-python-3	(revision 28178)
@@ -46,5 +46,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux-static.sh
+	petsc		install-3.20-linux-static.sh
 	gsl			install-static.sh
 	boost		install-1.7-linux-static.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-codipack
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-codipack	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-codipack	(revision 28178)
@@ -39,5 +39,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	gsl			install.sh
 	triangle	install-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-dakota
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-dakota	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-dakota	(revision 28178)
@@ -44,5 +44,5 @@
 	autotools		install-linux.sh
 	cmake			install.sh
-	petsc			install-3.17-linux.sh
+	petsc			install-3.20-linux.sh
 	gsl				install.sh
 	boost			install-1.7-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-full
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-full	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-full	(revision 28178)
@@ -45,5 +45,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	gsl			install.sh
 	boost		install-1.7-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-full-mplapack
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-full-mplapack	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-full-mplapack	(revision 28178)
@@ -44,5 +44,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	mplapack	install-2-linux.sh
 	gsl			install.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-full-valgrind
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-full-valgrind	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-full-valgrind	(revision 28178)
@@ -44,5 +44,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	gsl			install.sh
 	boost		install-1.7-linux-valgrind.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-gia
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-gia	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-gia	(revision 28178)
@@ -37,5 +37,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	triangle	install-linux.sh
 	math77		install.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-iceocean
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-iceocean	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-iceocean	(revision 28178)
@@ -34,5 +34,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	triangle	install-linux.sh
 	m1qn3		install-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-python
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-python	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-python	(revision 28178)
@@ -33,5 +33,5 @@
 	autotools	install-linux.sh
 	cmake		install.sh
-	petsc		install-3.17-linux.sh
+	petsc		install-3.20-linux.sh
 	triangle	install-linux.sh
 	m1qn3		install-linux.sh
Index: /issm/trunk-jpl/jenkins/ross-debian_linux-solid_earth
===================================================================
--- /issm/trunk-jpl/jenkins/ross-debian_linux-solid_earth	(revision 28177)
+++ /issm/trunk-jpl/jenkins/ross-debian_linux-solid_earth	(revision 28178)
@@ -42,5 +42,5 @@
 	autotools		install-linux.sh
 	cmake			install.sh
-	petsc			install-3.17-linux.sh
+	petsc			install-3.20-linux.sh
 	gsl				install.sh
 	boost			install-1.7-linux.sh

Index: /issm/trunk-jpl/externalpackages/gmt/install-6-linux-static.sh
===================================================================
--- /issm/trunk-jpl/externalpackages/gmt/install-6-linux-static.sh	(revision 28177)
+++ /issm/trunk-jpl/externalpackages/gmt/install-6-linux-static.sh	(revision 28178)
@@ -5,5 +5,7 @@
 ## Constants
 #
-VER="6.0.0"
+VER="6.5.0"
+
+PREFIX="${ISSM_DIR}/externalpackages/gmt/install"
 
 # Find libgfortran and libgcc so we do not have to hardcode them
@@ -27,5 +29,4 @@
 export CURL_INCLUDE_DIRS="${CURL_ROOT}/include"
 export CURL_LIBRARIES="${CURL_ROOT}/lib/libcurl.a;/usr/lib/x86_64-linux-gnu/libssl.a;/usr/lib/x86_64-linux-gnu/libcrypto.a"
-export PREFIX="${ISSM_DIR}/externalpackages/gmt/install" # NOTE: Need to export this to be picked up by customized ConfigUser.cmake (see below). Set to location where external package should be installed.
 
 # Download source
@@ -43,10 +44,12 @@
 rm -rf gmt-${VER}
 
-# Copy custom configuration files
-cp ./configs/6.0/static/linux/cmake/ConfigUser.static.cmake ./src/cmake/ConfigUser.cmake
-cp ./configs/6.0/static/cmake/modules/FindGDAL.cmake ./src/cmake/modules
-cp ./configs/6.0/static/cmake/modules/FindGSHHG.cmake ./src/cmake/modules
-cp ./configs/6.0/static/cmake/modules/FindNETCDF.cmake ./src/cmake/modules
-cp ./configs/6.0/static/src/CMakeLists.txt ./src/src
+# Copy custom configuration files to source
+cp ./src/cmake/ConfigUserAdvancedTemplate.cmake ./src/cmake/ConfigUser.cmake
+
+# Patch source
+patch ./src/cmake/ConfigUser.cmake < ./configs/${VER%.*}/static/cmake/ConfigUserAdvancedTemplate.cmake.patch
+patch ./src/cmake/modules/FindGDAL.cmake < ./configs/${VER%.*}/static/cmake/modules/FindGDAL.cmake.patch
+patch ./src/cmake/modules/FindGSHHG.cmake < ./configs/${VER%.*}/static/cmake/modules/FindGSHHG.cmake.patch
+patch ./src/cmake/modules/FindNETCDF.cmake < ./configs/${VER%.*}/static/cmake/modules/FindNETCDF.cmake.patch
 
 # Configure
@@ -63,4 +66,5 @@
 #
 cmake \
+	-DCMAKE_INSTALL_PREFIX="${PREFIX}" \
 	-DBLAS_LIBRARIES="${BLAS_ROOT}/lib/libfblas.a;${LIBGFORTRAN_ROOT}/libgfortran.a;${LIBGFORTRAN_ROOT}/libquadmath.a;${LIBGCC}" \
 	-DCURL_INCLUDE_DIR="${CURL_ROOT}/include" \
Index: /issm/trunk-jpl/externalpackages/gmt/install-6-linux.sh
===================================================================
--- /issm/trunk-jpl/externalpackages/gmt/install-6-linux.sh	(revision 28177)
+++ /issm/trunk-jpl/externalpackages/gmt/install-6-linux.sh	(revision 28178)
@@ -5,5 +5,7 @@
 ## Constants
 #
-VER="6.4.0"
+VER="6.5.0"
+
+PREFIX="${ISSM_DIR}/externalpackages/gmt/install"
 
 # Find libgfortran so that we do not have to hardcode it.
@@ -19,5 +21,4 @@
 #
 export CC=mpicc
-export PREFIX="${ISSM_DIR}/externalpackages/gmt/install" # NOTE: Need to export this to be picked up by customized ConfigUser.cmake (see below). Set to location where external package should be installed.
 
 # Download source
@@ -35,6 +36,9 @@
 rm -rf gmt-${VER}
 
-# Copy custom configuration files
-cp ./configs/6.0/linux/cmake/ConfigUser.cmake ./src/cmake
+# Copy custom configuration files to source
+cp ./src/cmake/ConfigUserAdvancedTemplate.cmake ./src/cmake/ConfigUser.cmake
+
+# Patch source
+patch ./src/cmake/ConfigUser.cmake < ./configs/${VER%.*}/cmake/ConfigUserAdvancedTemplate.cmake.patch
 
 # Configure
@@ -51,4 +55,5 @@
 #
 cmake \
+	-DCMAKE_INSTALL_PREFIX="${PREFIX}" \
 	-DBLAS_LIBRARIES="-L${BLAS_ROOT}/lib;-lfblas;-L${LIBGFORTRAN_ROOT};-lgfortran" \
 	-DCURL_INCLUDE_DIR="${CURL_ROOT}/include" \
Index: /issm/trunk-jpl/externalpackages/gmt/install-6-mac.sh
===================================================================
--- /issm/trunk-jpl/externalpackages/gmt/install-6-mac.sh	(revision 28177)
+++ /issm/trunk-jpl/externalpackages/gmt/install-6-mac.sh	(revision 28178)
@@ -5,5 +5,7 @@
 ## Constants
 #
-VER="6.4.0"
+VER="6.5.0"
+
+PREFIX="${ISSM_DIR}/externalpackages/gmt/install"
 
 # Find libgfortran so that we do not have to hardcode it.
@@ -19,5 +21,4 @@
 #
 export CC=mpicc
-export PREFIX="${ISSM_DIR}/externalpackages/gmt/install" # NOTE: Need to export this to be picked up by customized ConfigUser.cmake (see below). Set to location where external package should be installed.
 
 # Download source
@@ -35,7 +36,10 @@
 rm -rf gmt-${VER}
 
-# Copy custom configuration files
-cp ./configs/6/mac/cmake/ConfigUser.cmake ./src/cmake
-cp ./configs/6/mac/cmake/modules/ConfigCMake.cmake ./src/cmake/modules
+# Copy custom configuration files to source
+cp ./src/cmake/ConfigUserAdvancedTemplate.cmake ./src/cmake/ConfigUser.cmake
+
+# Patch source
+patch ./src/cmake/ConfigUser.cmake < ./configs/${VER%.*}/cmake/ConfigUserAdvancedTemplate.cmake.patch
+patch ./src/cmake/modules/ConfigCMake.cmake < ./configs/${VER%.*}/cmake/modules/ConfigCMake.cmake.patch
 
 # Configure
@@ -52,4 +56,5 @@
 #
 cmake \
+	-DCMAKE_INSTALL_PREFIX="${PREFIX}" \
 	-DBLAS_LIBRARIES="-L${BLAS_ROOT}/lib;-lfblas;-L${LIBGFORTRAN_ROOT};-lgfortran" \
 	-DCURL_INCLUDE_DIR="${CURL_ROOT}/include" \